@@ -54,7 +54,6 @@
 #include "nsComponentManagerUtils.h"
 #include "nsServiceManagerUtils.h"
 #include "nsIServiceManager.h"
-#include "nsIProxyObjectManager.h"
 #include "nsIObserver.h"
 #include "nsIProcess.h"
 #include "nsIURI.h"
@@ -1076,14 +1075,20 @@ nsPipeTransport::CopyArgsAndCreateProcess(const PRUnichar **args,
 
   for (j=0; j < argCount; j++) {
 #ifdef XP_OS2
-    nsCAutoString tmpArg ( args[j] );
+    nsAutoString tmpArg (args[j]);
+    nsAutoString quote;
+    quote.AssignASCII("\"");
     if (tmpArg.FindChar(' ', 0) >= 0) {
-      tmpArg.Insert("\"", 0);
-      tmpArg.Append("\"");
-      args[j] = ToNewUTF8String(tmpArg);
+       tmpArg.Insert(quote, 0);
+       tmpArg.Append(quote);
+       argList[j+1] = ToNewUTF8String(tmpArg);
     }
-#endif
+    else {
+        argList[j+1] = ToNewUTF8String(nsDependentString(args[j]));
+    }
+#else
     argList[j+1] = ToNewUTF8String(nsDependentString(args[j]));
+#endif
     DEBUG_LOG(("nsPipeTransport::CopyArgsAndCreateProcess: arg[%d] = %s\n",
       j+1, argList[j+1]));
   }
@@ -1686,12 +1691,6 @@ nsPipeTransport::AsyncRead(nsIStreamListener *listener,
     // Always block output
     IPCBool nonBlockingOutput = PR_FALSE;
 
-    // Now generate proxied pipe observer/listener to enable async calling
-    // from the polling thread to the current (UI?) thread
-    nsCOMPtr<nsIProxyObjectManager> proxyMgr =
-                              do_GetService(NS_XPCOMPROXY_CONTRACTID, &rv);
-    NS_ENSURE_SUCCESS(rv, rv);
-
     // Open pipe to handle STDOUT
     nsCOMPtr<nsIAsyncInputStream> asyncInputStream;
     nsCOMPtr<nsIAsyncOutputStream> asyncOutputStream;
